@@ -4,7 +4,9 @@ import (
 	"fmt"
 	"os"
 	"path/filepath"
+	"regexp"
 	"runtime"
+	"strings"
 
 	"github.com/gdamore/tcell/v2"
 	"github.com/mattn/go-isatty"
@@ -36,6 +38,7 @@ However HDDs work as well, but the performance gain is not so huge.
 func init() {
 	af = &app.Flags{}
 	flags := rootCmd.Flags()
+	flags.StringVar(&af.CfgFile, "config-file", "", "Read config from file (default is $HOME/.gdu.yaml)")
 	flags.StringVarP(&af.LogFile, "log-file", "l", "/dev/null", "Path to a logfile")
 	flags.StringVarP(&af.OutputFile, "output-file", "o", "", "Export all info into file as JSON")
 	flags.StringVarP(&af.InputFile, "input-file", "f", "", "Import analysis from JSON file")
@@ -66,22 +69,39 @@ func init() {
 }
 
 func initConfig() {
-	if af.CfgFile == "" {
-		home, err := os.UserHomeDir()
-		if err != nil {
-			configErr = err
-			return
-		}
-		af.CfgFile = filepath.Join(home, ".gdu.yaml")
-	}
+	setConfigFilePath()
 	data, err := os.ReadFile(af.CfgFile)
 	if err != nil {
+		configErr = err
 		return // config file does not exist, return
 	}
 
 	configErr = yaml.Unmarshal(data, &af)
 }
 
+func setConfigFilePath() {
+	command := strings.Join(os.Args, " ")
+	if strings.Contains(command, "--config-file") {
+		re := regexp.MustCompile("--config-file[= ]([^ ]+)")
+		parts := re.FindStringSubmatch(command)
+
+		if len(parts) > 1 {
+			af.CfgFile = parts[1]
+			return
+		}
+	}
+	setDefaultConfigFilePath()
+}
+
+func setDefaultConfigFilePath() {
+	home, err := os.UserHomeDir()
+	if err != nil {
+		configErr = err
+		return
+	}
+	af.CfgFile = filepath.Join(home, ".gdu.yaml")
+}
+
 func runE(command *cobra.Command, args []string) error {
 	var (
 		termApp *tview.Application
@@ -94,12 +114,19 @@ func runE(command *cobra.Command, args []string) error {
 		if err != nil {
 			return fmt.Errorf("Error marshaling config file: %w", err)
 		}
+		if af.CfgFile == "" {
+			setDefaultConfigFilePath()
+		}
 		err = os.WriteFile(af.CfgFile, data, 0600)
 		if err != nil {
-			return fmt.Errorf("Error writing config file: %w", err)
+			return fmt.Errorf("Error writing config file %s: %w", af.CfgFile, err)
 		}
 	}
 
+	if runtime.GOOS == "windows" && af.LogFile == "/dev/null" {
+		af.LogFile = "nul"
+	}
+
 	var f *os.File
 	if af.LogFile == "-" {
 		f = os.Stdout
@@ -127,9 +154,6 @@ func runE(command *cobra.Command, args []string) error {
 	if runtime.GOOS == "windows" || runtime.GOOS == "plan9" {
 		af.ShowApparentSize = true
 	}
-	if runtime.GOOS == "windows" && af.LogFile == "/dev/null" {
-		af.LogFile = "nul"
-	}
 
 	if !af.ShowVersion && !af.NonInteractive && istty && af.OutputFile == "" {
 		screen, err = tcell.NewScreen()
